Module kvs

Module kvs 

Key-value store.

This module provides access to the host’s key-value store. You should be able to manage keys, values, and stores from within your functions.

Note: stores are based on namespace set within a function. This allows for multiple stores per function, persisting instance state.

Structs

Storage
Key-value storage endpoints.